==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/flac/translations/flac_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>Файли FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="151"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Про аудіо-модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="152"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудіо-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="153"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Length</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Sample rate</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Input/flac/translations/flac_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>Файли FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="172"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Про аудіо-модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="173"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудіо-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="174"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Length</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Sample rate</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>Bitrate</source>
        <translation>Бітрейт</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>
